Hbb

Struct Hbb 

pub struct Hbb { /* private fields */ }
Horizontal bounding box with position, size, and metadata.

Implementations

Source

impl Hbb

pub fn with_x(self, x: f32) -> Self

Sets the value of the x field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn x(&self) -> f32

Returns the value of the x field.

pub fn with_y(self, x: f32) -> Self

Sets the value of the y field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn y(&self) -> f32

Returns the value of the y field.

pub fn with_w(self, x: f32) -> Self

Sets the value of the w field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn w(&self) -> f32

Returns the value of the w field.

pub fn with_h(self, x: f32) -> Self

Sets the value of the h field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn h(&self) -> f32

Returns the value of the h field.

pub fn with_meta(self, x: InstanceMeta) -> Self

Sets the value of the meta field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn meta(&self) -> &InstanceMeta

Returns a reference to the meta field.

pub fn with_style(self, x: Style) -> Self

Sets the value of the optional style field.

Arguments
  • x - The value to be wrapped in Some and assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn style(&self) -> Option<&Style>

Returns an optional reference to the style field.

pub fn with_keypoints(self, x: &[Keypoint]) -> Self

Sets the value of the optional keypoints field from a slice.

Arguments
  • x - A slice of elements to be converted into a vector and wrapped in Some.
Returns

Returns Self to allow method chaining.

pub fn keypoints(&self) -> Option<&[Keypoint]>

Returns an optional slice of the keypoints field.

Source

impl Hbb

pub fn with_track_id(self, track_id: usize) -> Self

pub fn track_id(&self) -> Option<usize>

pub fn with_uid(self, uid: usize) -> Self

pub fn with_id(self, id: usize) -> Self

pub fn with_name(self, name: &str) -> Self

pub fn with_confidence(self, confidence: f32) -> Self

pub fn uid(&self) -> usize

pub fn name(&self) -> Option<&str>

pub fn confidence(&self) -> Option<f32>

pub fn id(&self) -> Option<usize>

pub fn from_xywh(x: f32, y: f32, w: f32, h: f32) -> Self

pub fn from_xyxy(x1: f32, y1: f32, x2: f32, y2: f32) -> Self

pub fn from_cxcywh(cx: f32, cy: f32, w: f32, h: f32) -> Self

pub fn with_xyxy(self, x1: f32, y1: f32, x2: f32, y2: f32) -> Self

pub fn with_xywh(self, x: f32, y: f32, w: f32, h: f32) -> Self

pub fn with_cxcywh(self, cx: f32, cy: f32, w: f32, h: f32) -> Self

pub fn width(&self) -> f32

pub fn height(&self) -> f32

pub fn xmin(&self) -> f32

pub fn ymin(&self) -> f32

pub fn xmax(&self) -> f32

pub fn ymax(&self) -> f32

pub fn cx(&self) -> f32

pub fn cy(&self) -> f32

pub fn xyxy(&self) -> (f32, f32, f32, f32)

pub fn xywh(&self) -> (f32, f32, f32, f32)

pub fn cxywh(&self) -> (f32, f32, f32, f32)

pub fn cxcyah(&self) -> (f32, f32, f32, f32)

Returns: (center_x, center_y, aspect_ratio, height)

pub fn area(&self) -> f32

pub fn perimeter(&self) -> f32

pub fn is_squre(&self) -> bool

pub fn intersect(&self, other: &Hbb) -> f32

pub fn union(&self, other: &Hbb) -> f32

pub fn iou(&self, other: &Self) -> f32

pub fn contains(&self, other: &Hbb) -> bool

pub fn to_polygon(&self) -> Polygon