Mask

Struct Mask 

pub struct Mask { /* private fields */ }
Mask: Gray Image.

Implementations

Source

impl Mask

pub fn with_mask(self, x: GrayImage) -> Self

Sets the mask field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = Mask::default().with_mask(value);

Generated by aksr - Builder pattern macro

pub fn mask(&self) -> &GrayImage

Returns a reference to the mask field.

Example
let obj = Mask::default();
let value = obj.mask();

Generated by aksr - Builder pattern macro

pub fn into_mask(self) -> GrayImage

Consumes self and returns the mask field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type GrayImage.

Example
let obj = Mask::default().with_mask(value);
let value = obj.into_mask();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_meta(self, x: InstanceMeta) -> Self

Sets the meta field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = Mask::default().with_meta(value);

Generated by aksr - Builder pattern macro

pub fn meta(&self) -> &InstanceMeta

Returns a reference to the meta field.

Example
let obj = Mask::default();
let value = obj.meta();

Generated by aksr - Builder pattern macro

pub fn into_meta(self) -> InstanceMeta

Consumes self and returns the meta field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type InstanceMeta.

Example
let obj = Mask::default().with_meta(value);
let value = obj.into_meta();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_style(self, x: MaskStyle) -> Self

Sets the optional style field.

Arguments
  • x - The value that will be automatically wrapped in Some
Returns

Returns Self for method chaining.

Note

The value is automatically wrapped in Some, so you don’t need to pass Some(value).

Example
let obj = Mask::default().with_style(value);

Generated by aksr - Builder pattern macro

pub fn style(&self) -> Option<&MaskStyle>

Returns an optional reference to the style field.

Example
let obj = Mask::default();
let value = obj.style();

Generated by aksr - Builder pattern macro

pub fn into_style(self) -> Option<MaskStyle>

Consumes self and returns the style field.

This method moves the owned value out of the struct without cloning.

Returns

Returns Option containing the field value, or None if the field was None.

Example
let obj = Mask::default().with_style(value);
let value = obj.into_style();

Generated by aksr - Builder pattern macro

pub fn take_style(&mut self) -> Option<MaskStyle>

Takes the style field, leaving None in its place.

This method moves the value out and replaces it with None, allowing you to continue using the struct.

Returns

Returns Option containing the field value, or None if the field was None.

Note

This does not require the inner type to implement Default.

Example
let mut obj = Mask::default().with_style(value);
let value = obj.take_style();
// obj.style is now None

Generated by aksr - Builder pattern macro

Source

impl Mask

pub fn with_track_id(self, track_id: usize) -> Self

pub fn track_id(&self) -> Option<usize>

pub fn with_uid(self, uid: usize) -> Self

pub fn with_id(self, id: usize) -> Self

pub fn with_name(self, name: &str) -> Self

pub fn with_confidence(self, confidence: f32) -> Self

pub fn uid(&self) -> usize

pub fn name(&self) -> Option<&str>

pub fn confidence(&self) -> Option<f32>

pub fn id(&self) -> Option<usize>

pub fn new(u8s: &[u8], width: u32, height: u32) -> Result<Self>

pub fn to_vec(&self) -> Vec<u8>

pub fn height(&self) -> u32

pub fn width(&self) -> u32

pub fn dimensions(&self) -> (u32, u32)

pub fn polygon(&self) -> Option<Polygon>

pub fn polygons(&self) -> Vec<Polygon>