pub struct ProcessorConfig {Show 25 fields
pub image_width: Option<u32>,
pub image_height: Option<u32>,
pub do_resize: bool,
pub resize_mode: ResizeMode,
pub resize_filter: Option<&'static str>,
pub padding_value: u8,
pub normalize: bool,
pub image_std: Vec<f32>,
pub image_mean: Vec<f32>,
pub nchw: bool,
pub unsigned: bool,
pub pad_image: bool,
pub pad_size: usize,
pub up_scale: f32,
pub image_tensor_layout: ImageTensorLayout,
pub model_max_length: Option<u64>,
pub tokenizer_file: Option<String>,
pub config_file: Option<String>,
pub special_tokens_map_file: Option<String>,
pub tokenizer_config_file: Option<String>,
pub generation_config_file: Option<String>,
pub vocab_file: Option<String>,
pub vocab_txt: Option<String>,
pub temperature: f32,
pub topp: f32,
}Expand description
Configuration for image and text processing pipelines.
Fields
image_width: Option<u32>Target image width for resizing.
image_height: Option<u32>Target image height for resizing.
do_resize: boolWhether to resize the image.
resize_mode: ResizeModeImage resizing mode.
resize_filter: Option<&'static str>Image resize filter algorithm.
padding_value: u8Padding value for image borders.
normalize: boolWhether to normalize image values.
image_std: Vec<f32>Standard deviation values for normalization.
image_mean: Vec<f32>Mean values for normalization.
nchw: boolWhether to use NCHW format (channels first).
unsigned: boolWhether to use unsigned integer format.
pad_image: boolWhether to pad image for super resolution.
pad_size: usizePadding size for super resolution.
up_scale: f32Up-scaling factor for super resolution.
image_tensor_layout: ImageTensorLayoutImage tensor layout format.
model_max_length: Option<u64>Maximum sequence length for tokenization.
tokenizer_file: Option<String>Path to tokenizer file.
config_file: Option<String>Path to model configuration file.
special_tokens_map_file: Option<String>Path to special tokens mapping file.
tokenizer_config_file: Option<String>Path to tokenizer configuration file.
generation_config_file: Option<String>Path to generation configuration file.
vocab_file: Option<String>Path to vocabulary file.
vocab_txt: Option<String>Path to vocabulary text file.
temperature: f32Temperature parameter for text generation.
topp: f32Top-p parameter for nucleus sampling.
Implementations
Sourceimpl ProcessorConfig
impl ProcessorConfig
Sourcepub fn with_image_width(self, x: u32) -> Self
pub fn with_image_width(self, x: u32) -> Self
Sets the optional image_width field.
Arguments
x- The value that will be automatically wrapped inSome
Returns
Returns Self for method chaining.
Note
The value is automatically wrapped in Some, so you don’t need to pass Some(value).
Example
let obj = ProcessorConfig::default().with_image_width(value);Generated by aksr - Builder pattern macro
Sourcepub fn image_width(&self) -> Option<u32>
pub fn image_width(&self) -> Option<u32>
Sourcepub fn into_image_width(self) -> Option<u32>
pub fn into_image_width(self) -> Option<u32>
Consumes self and returns the image_width field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_image_width(value);
let value = obj.into_image_width();Generated by aksr - Builder pattern macro
Sourcepub fn take_image_width(&mut self) -> Option<u32>
pub fn take_image_width(&mut self) -> Option<u32>
Takes the image_width field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_image_width(value);
let value = obj.take_image_width();
// obj.image_width is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_image_height(self, x: u32) -> Self
pub fn with_image_height(self, x: u32) -> Self
Sets the optional image_height field.
Arguments
x- The value that will be automatically wrapped inSome
Returns
Returns Self for method chaining.
Note
The value is automatically wrapped in Some, so you don’t need to pass Some(value).
Example
let obj = ProcessorConfig::default().with_image_height(value);Generated by aksr - Builder pattern macro
Sourcepub fn image_height(&self) -> Option<u32>
pub fn image_height(&self) -> Option<u32>
Sourcepub fn into_image_height(self) -> Option<u32>
pub fn into_image_height(self) -> Option<u32>
Consumes self and returns the image_height field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_image_height(value);
let value = obj.into_image_height();Generated by aksr - Builder pattern macro
Sourcepub fn take_image_height(&mut self) -> Option<u32>
pub fn take_image_height(&mut self) -> Option<u32>
Takes the image_height field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_image_height(value);
let value = obj.take_image_height();
// obj.image_height is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_do_resize(self, x: bool) -> Self
pub fn with_do_resize(self, x: bool) -> Self
Sourcepub fn with_resize_mode(self, x: ResizeMode) -> Self
pub fn with_resize_mode(self, x: ResizeMode) -> Self
Sourcepub fn resize_mode(&self) -> &ResizeMode
pub fn resize_mode(&self) -> &ResizeMode
Sourcepub fn into_resize_mode(self) -> ResizeMode
pub fn into_resize_mode(self) -> ResizeMode
Consumes self and returns the resize_mode field.
This method moves the owned value out of the struct without cloning.
Returns
Returns the owned value of type ResizeMode.
Example
let obj = ProcessorConfig::default().with_resize_mode(value);
let value = obj.into_resize_mode();
// obj is now consumed and cannot be usedGenerated by aksr - Builder pattern macro
Sourcepub fn with_resize_filter(self, x: &'static str) -> Self
pub fn with_resize_filter(self, x: &'static str) -> Self
Sets the optional resize_filter field.
Arguments
x- The value that will be automatically wrapped inSome
Returns
Returns Self for method chaining.
Note
The value is automatically wrapped in Some, so you don’t need to pass Some(value).
Example
let obj = ProcessorConfig::default().with_resize_filter(value);Generated by aksr - Builder pattern macro
Sourcepub fn resize_filter(&self) -> Option<&'static str>
pub fn resize_filter(&self) -> Option<&'static str>
Sourcepub fn into_resize_filter(self) -> Option<&'static str>
pub fn into_resize_filter(self) -> Option<&'static str>
Consumes self and returns the resize_filter field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option<& ’static str> containing the field value, or None if the field was None.
Example
let obj = ProcessorConfig::default().with_resize_filter(value);
let value = obj.into_resize_filter();Generated by aksr - Builder pattern macro
Sourcepub fn take_resize_filter(&mut self) -> Option<&'static str>
pub fn take_resize_filter(&mut self) -> Option<&'static str>
Takes the resize_filter field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option<& ’static str> containing the field value, or None if the field was None.
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_resize_filter(value);
let value = obj.take_resize_filter();
// obj.resize_filter is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_padding_value(self, x: u8) -> Self
pub fn with_padding_value(self, x: u8) -> Self
Sourcepub fn padding_value(&self) -> u8
pub fn padding_value(&self) -> u8
Sourcepub fn with_normalize(self, x: bool) -> Self
pub fn with_normalize(self, x: bool) -> Self
Sourcepub fn with_image_std(self, x: &[f32]) -> Self
pub fn with_image_std(self, x: &[f32]) -> Self
Sets the image_std field from a slice.
Arguments
x- A slice of elements to be converted into a vector
Returns
Returns Self for method chaining.
Note
If the slice is empty, the field remains unchanged.
Example
let obj = ProcessorConfig::default().with_image_std(&[item1, item2]);Generated by aksr - Builder pattern macro
Sourcepub fn into_image_std(self) -> Vec<f32>
pub fn into_image_std(self) -> Vec<f32>
Consumes self and returns the image_std field.
This method moves the owned value out of the struct without cloning.
Returns
Returns the owned value of type Vec < f32 >.
Example
let obj = ProcessorConfig::default().with_image_std(value);
let value = obj.into_image_std();
// obj is now consumed and cannot be usedGenerated by aksr - Builder pattern macro
Sourcepub fn take_image_std(&mut self) -> Vec<f32>
pub fn take_image_std(&mut self) -> Vec<f32>
Takes the image_std field and replaces it with Default::default().
This method moves the value out and replaces it with the default value, allowing you to continue using the struct.
Returns
Returns the owned value of type Vec < f32 >.
Note
Requires the field type Vec < f32 > to implement Default. Prefer this when you want to keep using the instance.
Example
let mut obj = ProcessorConfig::default().with_image_std(value);
let value = obj.take_image_std();
// obj.image_std is now set to Default::default()Generated by aksr - Builder pattern macro
Sourcepub fn with_image_mean(self, x: &[f32]) -> Self
pub fn with_image_mean(self, x: &[f32]) -> Self
Sets the image_mean field from a slice.
Arguments
x- A slice of elements to be converted into a vector
Returns
Returns Self for method chaining.
Note
If the slice is empty, the field remains unchanged.
Example
let obj = ProcessorConfig::default().with_image_mean(&[item1, item2]);Generated by aksr - Builder pattern macro
Sourcepub fn image_mean(&self) -> &[f32]
pub fn image_mean(&self) -> &[f32]
Sourcepub fn into_image_mean(self) -> Vec<f32>
pub fn into_image_mean(self) -> Vec<f32>
Consumes self and returns the image_mean field.
This method moves the owned value out of the struct without cloning.
Returns
Returns the owned value of type Vec < f32 >.
Example
let obj = ProcessorConfig::default().with_image_mean(value);
let value = obj.into_image_mean();
// obj is now consumed and cannot be usedGenerated by aksr - Builder pattern macro
Sourcepub fn take_image_mean(&mut self) -> Vec<f32>
pub fn take_image_mean(&mut self) -> Vec<f32>
Takes the image_mean field and replaces it with Default::default().
This method moves the value out and replaces it with the default value, allowing you to continue using the struct.
Returns
Returns the owned value of type Vec < f32 >.
Note
Requires the field type Vec < f32 > to implement Default. Prefer this when you want to keep using the instance.
Example
let mut obj = ProcessorConfig::default().with_image_mean(value);
let value = obj.take_image_mean();
// obj.image_mean is now set to Default::default()Generated by aksr - Builder pattern macro
Sourcepub fn with_unsigned(self, x: bool) -> Self
pub fn with_unsigned(self, x: bool) -> Self
Sourcepub fn with_pad_image(self, x: bool) -> Self
pub fn with_pad_image(self, x: bool) -> Self
Sourcepub fn with_pad_size(self, x: usize) -> Self
pub fn with_pad_size(self, x: usize) -> Self
Sourcepub fn with_up_scale(self, x: f32) -> Self
pub fn with_up_scale(self, x: f32) -> Self
Sourcepub fn with_image_tensor_layout(self, x: ImageTensorLayout) -> Self
pub fn with_image_tensor_layout(self, x: ImageTensorLayout) -> Self
Sourcepub fn image_tensor_layout(&self) -> &ImageTensorLayout
pub fn image_tensor_layout(&self) -> &ImageTensorLayout
Sourcepub fn into_image_tensor_layout(self) -> ImageTensorLayout
pub fn into_image_tensor_layout(self) -> ImageTensorLayout
Consumes self and returns the image_tensor_layout field.
This method moves the owned value out of the struct without cloning.
Returns
Returns the owned value of type ImageTensorLayout.
Example
let obj = ProcessorConfig::default().with_image_tensor_layout(value);
let value = obj.into_image_tensor_layout();
// obj is now consumed and cannot be usedGenerated by aksr - Builder pattern macro
Sourcepub fn with_model_max_length(self, x: u64) -> Self
pub fn with_model_max_length(self, x: u64) -> Self
Sets the optional model_max_length field.
Arguments
x- The value that will be automatically wrapped inSome
Returns
Returns Self for method chaining.
Note
The value is automatically wrapped in Some, so you don’t need to pass Some(value).
Example
let obj = ProcessorConfig::default().with_model_max_length(value);Generated by aksr - Builder pattern macro
Sourcepub fn model_max_length(&self) -> Option<u64>
pub fn model_max_length(&self) -> Option<u64>
Sourcepub fn into_model_max_length(self) -> Option<u64>
pub fn into_model_max_length(self) -> Option<u64>
Consumes self and returns the model_max_length field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_model_max_length(value);
let value = obj.into_model_max_length();Generated by aksr - Builder pattern macro
Sourcepub fn take_model_max_length(&mut self) -> Option<u64>
pub fn take_model_max_length(&mut self) -> Option<u64>
Takes the model_max_length field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_model_max_length(value);
let value = obj.take_model_max_length();
// obj.model_max_length is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_tokenizer_file(self, x: &str) -> Self
pub fn with_tokenizer_file(self, x: &str) -> Self
Sets the optional tokenizer_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_tokenizer_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn tokenizer_file(&self) -> Option<&str>
pub fn tokenizer_file(&self) -> Option<&str>
Sourcepub fn into_tokenizer_file(self) -> Option<String>
pub fn into_tokenizer_file(self) -> Option<String>
Consumes self and returns the tokenizer_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_tokenizer_file(value);
let value = obj.into_tokenizer_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_tokenizer_file(&mut self) -> Option<String>
pub fn take_tokenizer_file(&mut self) -> Option<String>
Takes the tokenizer_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_tokenizer_file(value);
let value = obj.take_tokenizer_file();
// obj.tokenizer_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_config_file(self, x: &str) -> Self
pub fn with_config_file(self, x: &str) -> Self
Sets the optional config_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_config_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn config_file(&self) -> Option<&str>
pub fn config_file(&self) -> Option<&str>
Sourcepub fn into_config_file(self) -> Option<String>
pub fn into_config_file(self) -> Option<String>
Consumes self and returns the config_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_config_file(value);
let value = obj.into_config_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_config_file(&mut self) -> Option<String>
pub fn take_config_file(&mut self) -> Option<String>
Takes the config_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_config_file(value);
let value = obj.take_config_file();
// obj.config_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_special_tokens_map_file(self, x: &str) -> Self
pub fn with_special_tokens_map_file(self, x: &str) -> Self
Sets the optional special_tokens_map_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_special_tokens_map_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn special_tokens_map_file(&self) -> Option<&str>
pub fn special_tokens_map_file(&self) -> Option<&str>
Sourcepub fn into_special_tokens_map_file(self) -> Option<String>
pub fn into_special_tokens_map_file(self) -> Option<String>
Consumes self and returns the special_tokens_map_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_special_tokens_map_file(value);
let value = obj.into_special_tokens_map_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_special_tokens_map_file(&mut self) -> Option<String>
pub fn take_special_tokens_map_file(&mut self) -> Option<String>
Takes the special_tokens_map_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_special_tokens_map_file(value);
let value = obj.take_special_tokens_map_file();
// obj.special_tokens_map_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_tokenizer_config_file(self, x: &str) -> Self
pub fn with_tokenizer_config_file(self, x: &str) -> Self
Sets the optional tokenizer_config_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_tokenizer_config_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn tokenizer_config_file(&self) -> Option<&str>
pub fn tokenizer_config_file(&self) -> Option<&str>
Sourcepub fn into_tokenizer_config_file(self) -> Option<String>
pub fn into_tokenizer_config_file(self) -> Option<String>
Consumes self and returns the tokenizer_config_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_tokenizer_config_file(value);
let value = obj.into_tokenizer_config_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_tokenizer_config_file(&mut self) -> Option<String>
pub fn take_tokenizer_config_file(&mut self) -> Option<String>
Takes the tokenizer_config_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_tokenizer_config_file(value);
let value = obj.take_tokenizer_config_file();
// obj.tokenizer_config_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_generation_config_file(self, x: &str) -> Self
pub fn with_generation_config_file(self, x: &str) -> Self
Sets the optional generation_config_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_generation_config_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn generation_config_file(&self) -> Option<&str>
pub fn generation_config_file(&self) -> Option<&str>
Sourcepub fn into_generation_config_file(self) -> Option<String>
pub fn into_generation_config_file(self) -> Option<String>
Consumes self and returns the generation_config_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_generation_config_file(value);
let value = obj.into_generation_config_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_generation_config_file(&mut self) -> Option<String>
pub fn take_generation_config_file(&mut self) -> Option<String>
Takes the generation_config_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_generation_config_file(value);
let value = obj.take_generation_config_file();
// obj.generation_config_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_vocab_file(self, x: &str) -> Self
pub fn with_vocab_file(self, x: &str) -> Self
Sets the optional vocab_file field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_vocab_file("value");Generated by aksr - Builder pattern macro
Sourcepub fn vocab_file(&self) -> Option<&str>
pub fn vocab_file(&self) -> Option<&str>
Sourcepub fn into_vocab_file(self) -> Option<String>
pub fn into_vocab_file(self) -> Option<String>
Consumes self and returns the vocab_file field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_vocab_file(value);
let value = obj.into_vocab_file();Generated by aksr - Builder pattern macro
Sourcepub fn take_vocab_file(&mut self) -> Option<String>
pub fn take_vocab_file(&mut self) -> Option<String>
Takes the vocab_file field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_vocab_file(value);
let value = obj.take_vocab_file();
// obj.vocab_file is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_vocab_txt(self, x: &str) -> Self
pub fn with_vocab_txt(self, x: &str) -> Self
Sets the optional vocab_txt field from a string slice.
Arguments
x- A string slice that will be automatically converted toStringand wrapped inSome
Returns
Returns Self for method chaining.
Note
The string slice is automatically converted to String and wrapped in Some.
Example
let obj = ProcessorConfig::default().with_vocab_txt("value");Generated by aksr - Builder pattern macro
Sourcepub fn into_vocab_txt(self) -> Option<String>
pub fn into_vocab_txt(self) -> Option<String>
Consumes self and returns the vocab_txt field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = ProcessorConfig::default().with_vocab_txt(value);
let value = obj.into_vocab_txt();Generated by aksr - Builder pattern macro
Sourcepub fn take_vocab_txt(&mut self) -> Option<String>
pub fn take_vocab_txt(&mut self) -> Option<String>
Takes the vocab_txt field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = ProcessorConfig::default().with_vocab_txt(value);
let value = obj.take_vocab_txt();
// obj.vocab_txt is now NoneGenerated by aksr - Builder pattern macro
Sourcepub fn with_temperature(self, x: f32) -> Self
pub fn with_temperature(self, x: f32) -> Self
Sourcepub fn temperature(&self) -> f32
pub fn temperature(&self) -> f32