KeypointStyle

Struct KeypointStyle 

pub struct KeypointStyle { /* private fields */ }
Keypoint-specific style configuration.

Implementations

Source

impl KeypointStyle

pub fn with_visible(self, x: bool) -> Self

Sets the visible field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_visible(value);

Generated by aksr - Builder pattern macro

pub fn visible(&self) -> bool

Returns the value of the visible field.

Example
let obj = KeypointStyle::default();
let value = obj.visible();

Generated by aksr - Builder pattern macro

pub fn with_text_visible(self, x: bool) -> Self

Sets the text_visible field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_text_visible(value);

Generated by aksr - Builder pattern macro

pub fn text_visible(&self) -> bool

Returns the value of the text_visible field.

Example
let obj = KeypointStyle::default();
let value = obj.text_visible();

Generated by aksr - Builder pattern macro

pub fn with_draw_fill(self, x: bool) -> Self

Sets the draw_fill field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_draw_fill(value);

Generated by aksr - Builder pattern macro

pub fn draw_fill(&self) -> bool

Returns the value of the draw_fill field.

Example
let obj = KeypointStyle::default();
let value = obj.draw_fill();

Generated by aksr - Builder pattern macro

pub fn with_draw_outline(self, x: bool) -> Self

Sets the draw_outline field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_draw_outline(value);

Generated by aksr - Builder pattern macro

pub fn draw_outline(&self) -> bool

Returns the value of the draw_outline field.

Example
let obj = KeypointStyle::default();
let value = obj.draw_outline();

Generated by aksr - Builder pattern macro

pub fn with_fill_color(self, x: ColorSource) -> Self

Sets the fill_color field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_fill_color(value);

Generated by aksr - Builder pattern macro

pub fn fill_color(&self) -> &ColorSource

Returns a reference to the fill_color field.

Example
let obj = KeypointStyle::default();
let value = obj.fill_color();

Generated by aksr - Builder pattern macro

pub fn into_fill_color(self) -> ColorSource

Consumes self and returns the fill_color field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type ColorSource.

Example
let obj = KeypointStyle::default().with_fill_color(value);
let value = obj.into_fill_color();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_outline_color(self, x: ColorSource) -> Self

Sets the outline_color field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_outline_color(value);

Generated by aksr - Builder pattern macro

pub fn outline_color(&self) -> &ColorSource

Returns a reference to the outline_color field.

Example
let obj = KeypointStyle::default();
let value = obj.outline_color();

Generated by aksr - Builder pattern macro

pub fn into_outline_color(self) -> ColorSource

Consumes self and returns the outline_color field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type ColorSource.

Example
let obj = KeypointStyle::default().with_outline_color(value);
let value = obj.into_outline_color();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_mode(self, x: KeypointStyleMode) -> Self

Sets the mode field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_mode(value);

Generated by aksr - Builder pattern macro

pub fn mode(&self) -> &KeypointStyleMode

Returns a reference to the mode field.

Example
let obj = KeypointStyle::default();
let value = obj.mode();

Generated by aksr - Builder pattern macro

pub fn into_mode(self) -> KeypointStyleMode

Consumes self and returns the mode field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type KeypointStyleMode.

Example
let obj = KeypointStyle::default().with_mode(value);
let value = obj.into_mode();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_radius(self, x: usize) -> Self

Sets the radius field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_radius(value);

Generated by aksr - Builder pattern macro

pub fn radius(&self) -> usize

Returns the value of the radius field.

Example
let obj = KeypointStyle::default();
let value = obj.radius();

Generated by aksr - Builder pattern macro

pub fn with_thickness(self, x: usize) -> Self

Sets the thickness field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_thickness(value);

Generated by aksr - Builder pattern macro

pub fn thickness(&self) -> usize

Returns the value of the thickness field.

Example
let obj = KeypointStyle::default();
let value = obj.thickness();

Generated by aksr - Builder pattern macro

pub fn with_skeleton(self, x: Skeleton) -> Self

Sets the optional skeleton field.

Arguments
  • x - The value that will be automatically wrapped in Some
Returns

Returns Self for method chaining.

Note

The value is automatically wrapped in Some, so you don’t need to pass Some(value).

Example
let obj = KeypointStyle::default().with_skeleton(value);

Generated by aksr - Builder pattern macro

pub fn skeleton(&self) -> Option<&Skeleton>

Returns an optional reference to the skeleton field.

Example
let obj = KeypointStyle::default();
let value = obj.skeleton();

Generated by aksr - Builder pattern macro

pub fn into_skeleton(self) -> Option<Skeleton>

Consumes self and returns the skeleton field.

This method moves the owned value out of the struct without cloning.

Returns

Returns Option containing the field value, or None if the field was None.

Example
let obj = KeypointStyle::default().with_skeleton(value);
let value = obj.into_skeleton();

Generated by aksr - Builder pattern macro

pub fn take_skeleton(&mut self) -> Option<Skeleton>

Takes the skeleton field, leaving None in its place.

This method moves the value out and replaces it with None, allowing you to continue using the struct.

Returns

Returns Option containing the field value, or None if the field was None.

Note

This does not require the inner type to implement Default.

Example
let mut obj = KeypointStyle::default().with_skeleton(value);
let value = obj.take_skeleton();
// obj.skeleton is now None

Generated by aksr - Builder pattern macro

pub fn with_skeleton_thickness(self, x: usize) -> Self

Sets the skeleton_thickness field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_skeleton_thickness(value);

Generated by aksr - Builder pattern macro

pub fn skeleton_thickness(&self) -> usize

Returns the value of the skeleton_thickness field.

Example
let obj = KeypointStyle::default();
let value = obj.skeleton_thickness();

Generated by aksr - Builder pattern macro

pub fn with_text_style(self, x: TextStyle) -> Self

Sets the text_style field.

Arguments
  • x - The new value to be assigned
Returns

Returns Self for method chaining.

Example
let obj = KeypointStyle::default().with_text_style(value);

Generated by aksr - Builder pattern macro

pub fn text_style(&self) -> &TextStyle

Returns a reference to the text_style field.

Example
let obj = KeypointStyle::default();
let value = obj.text_style();

Generated by aksr - Builder pattern macro

pub fn into_text_style(self) -> TextStyle

Consumes self and returns the text_style field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type TextStyle.

Example
let obj = KeypointStyle::default().with_text_style(value);
let value = obj.into_text_style();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn with_palette(self, x: &[Color]) -> Self

Sets the palette field from a slice.

Arguments
  • x - A slice of elements to be converted into a vector
Returns

Returns Self for method chaining.

Note

If the slice is empty, the field remains unchanged.

Example
let obj = KeypointStyle::default().with_palette(&[item1, item2]);

Generated by aksr - Builder pattern macro

pub fn palette(&self) -> &[Color]

Returns a slice view of the palette field.

Example
let obj = KeypointStyle::default();
let items = obj.palette();

Generated by aksr - Builder pattern macro

pub fn into_palette(self) -> Vec<Color>

Consumes self and returns the palette field.

This method moves the owned value out of the struct without cloning.

Returns

Returns the owned value of type Vec < Color >.

Example
let obj = KeypointStyle::default().with_palette(value);
let value = obj.into_palette();
// obj is now consumed and cannot be used

Generated by aksr - Builder pattern macro

pub fn take_palette(&mut self) -> Vec<Color>
where Vec<Color>: Default,

Takes the palette field and replaces it with Default::default().

This method moves the value out and replaces it with the default value, allowing you to continue using the struct.

Returns

Returns the owned value of type Vec < Color >.

Note

Requires the field type Vec < Color > to implement Default. Prefer this when you want to keep using the instance.

Example
let mut obj = KeypointStyle::default().with_palette(value);
let value = obj.take_palette();
// obj.palette is now set to Default::default()

Generated by aksr - Builder pattern macro

Source

impl KeypointStyle

pub fn star() -> Self

Keypoint with star shape

pub fn glow() -> Self

Keypoint with glow effect

pub fn show_confidence(self, show: bool) -> Self

Set show_confidence in text_style

pub fn show_id(self, show: bool) -> Self

Set show_id in text_style

pub fn show_name(self, show: bool) -> Self

Set show_name in text_style