Mask

Struct Mask 

pub struct Mask { /* private fields */ }
Mask: Gray Image.

Implementations

Source

impl Mask

pub fn with_mask(self, x: GrayImage) -> Self

Sets the value of the mask field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn mask(&self) -> &GrayImage

Returns a reference to the mask field.

pub fn with_meta(self, x: InstanceMeta) -> Self

Sets the value of the meta field.

Arguments
  • x - The new value to be assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn meta(&self) -> &InstanceMeta

Returns a reference to the meta field.

pub fn with_style(self, x: Style) -> Self

Sets the value of the optional style field.

Arguments
  • x - The value to be wrapped in Some and assigned to the field.
Returns

Returns Self to allow method chaining.

pub fn style(&self) -> Option<&Style>

Returns an optional reference to the style field.

Source

impl Mask

pub fn with_track_id(self, track_id: usize) -> Self

pub fn track_id(&self) -> Option<usize>

pub fn with_uid(self, uid: usize) -> Self

pub fn with_id(self, id: usize) -> Self

pub fn with_name(self, name: &str) -> Self

pub fn with_confidence(self, confidence: f32) -> Self

pub fn uid(&self) -> usize

pub fn name(&self) -> Option<&str>

pub fn confidence(&self) -> Option<f32>

pub fn id(&self) -> Option<usize>

pub fn new(u8s: &[u8], width: u32, height: u32) -> Result<Self>

pub fn to_vec(&self) -> Vec<u8>

pub fn height(&self) -> u32

pub fn width(&self) -> u32

pub fn dimensions(&self) -> (u32, u32)

pub fn polygon(&self) -> Option<Polygon>

pub fn polygons(&self) -> Vec<Polygon>