pub struct Version(pub u8, pub u8, pub Option<u8>);Expand description
Version representation with major, minor, and optional patch numbers.
Tuple Fields
0: u81: u82: Option<u8>Implementations
Sourceimpl Version
impl Version
Sourcepub fn with_2(self, x: u8) -> Self
pub fn with_2(self, x: u8) -> Self
Sets the optional 2 field.
Arguments
x- The value that will be automatically wrapped inSome
Returns
Returns Self for method chaining.
Note
The value is automatically wrapped in Some, so you don’t need to pass Some(value).
Example
let obj = Version::default().with_2(value);Generated by aksr - Builder pattern macro
Sourcepub fn into_nth_2(self) -> Option<u8>
pub fn into_nth_2(self) -> Option<u8>
Consumes self and returns the 2 field.
This method moves the owned value out of the struct without cloning.
Returns
Returns Option
Example
let obj = Version::default().with_2(value);
let value = obj.into_nth_2();Generated by aksr - Builder pattern macro
Sourcepub fn take_nth_2(&mut self) -> Option<u8>
pub fn take_nth_2(&mut self) -> Option<u8>
Takes the 2 field, leaving None in its place.
This method moves the value out and replaces it with None, allowing you to continue using the struct.
Returns
Returns Option
Note
This does not require the inner type to implement Default.
Example
let mut obj = Version::default().with_2(value);
let value = obj.take_nth_2();
// obj.2 is now NoneGenerated by aksr - Builder pattern macro